DecompressStarted

Struct DecompressStarted 

pub struct DecompressStarted<R> { /* private fields */ }
See methods on Decompress

Implementations

Source

impl<R> DecompressStarted<R>

pub fn color_space(&self) -> ColorSpace

pub fn min_flat_buffer_size(&self) -> usize

Gets the minimal buffer size for using DecompressStarted::read_scanlines_flat_into

pub fn read_raw_data(&mut self, image_dest: &mut [&mut Vec<JSAMPLE>])

Append data

pub fn width(&self) -> usize

pub fn height(&self) -> usize

pub fn read_scanlines<T: Pod>(&mut self) -> Result<Vec<T>>

Supports any pixel type that is marked as “plain old data”, see bytemuck crate.

Pixels can either have number of bytes matching number of channels, e.g. RGB as [u8; 3] or rgb::RGB8, or be an amorphous blob of u8s.

pub fn read_scanlines_into<'dest, T: Pod>( &mut self, dest: &'dest mut [T], ) -> Result<&'dest mut [T]>

Supports any pixel type that is marked as “plain old data”, see bytemuck crate. [u8; 3] and rgb::RGB8 are fine, for example. [u8] is allowed for any pixel type.

Allocation-less version of read_scanlines

pub fn read_scanlines_into_uninit<'dest, T: Pod>( &mut self, dest: &'dest mut [MaybeUninit<T>], ) -> Result<&'dest mut [T]>

Returns written-to slice

pub fn components(&self) -> &[CompInfo]

pub fn finish_into_inner(self) -> Result<R>
where R: BufRead,

Finish decompress and return the reader

pub fn finish(self) -> Result<()>